 # Geosoup 0.1.8

[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.3740290.svg)](https://doi.org/10.5281/zenodo.3740290)

Geosoup is a python package for geospatial data manipulation using GDAL and GDAL bindings in python.

This package is a minimalistic software distribution for limited manipulation of common geospatial data types such as rasters, vectors and samples. All the heavy lifting is done by GDAL, numpy and, scipy. 

Install using:

`pip install geosoup`


Note: Must have GDAL >= 2.1.3 up and running before installing this package.
